package net.locusworks.s3sync;

import net.locusworks.logger.ApplicationLogger;
import net.locusworks.logger.ApplicationLoggerFactory;
import net.locusworks.logger.ApplicationLoggerInitializer;
import net.locusworks.logger.LogLevel;
import net.locusworks.s3sync.client.FileManager;
import net.locusworks.s3sync.client.S3Client;
import net.locusworks.s3sync.conf.ConfigurationManager;

public class Entry {
  
  public static void main(String[] args) {
    
    ConfigurationManager conf = ConfigurationManager.getInstance();
    ApplicationLoggerFactory.init(new ApplicationLoggerInitializer() {

      @Override
      public LogLevel initialize() {
        return conf.getLogLevel();
      }
      
    });
    
    ApplicationLogger logger = ApplicationLoggerFactory.getLogger(Entry.class);
    
    if (System.getenv("AWS_ACCESS_KEY_ID") == null) {
      logger.error("AWS_ACCESS_KEY_ID is not set in environment variables");
      System.exit(-1);
    }
    
    if (System.getenv("AWS_SECRET_ACCESS_KEY") == null) {
      logger.error("AWS_SECRET_ACCESS_KEY is not set in environment variables");
      System.exit(-1);
    }
    
    logger.info("Starting S3 Sync");
    
    try (S3Client client = new S3Client(ConfigurationManager.getInstance())) {
      FileManager manager = FileManager.newInstance(client);
      client.syncFolder();
      manager.removeOrphanedFiles();
    } catch (Exception | Error e) {
      logger.error(e);
      System.exit(-1);
    } 
  }
}
